function A=randsdd(N,d,varargin)
% FUNCTION fc_amat.random.randsdd
% -- randsdd(N,d)
%      Return a N-by-d-by-d amat object whose matrices are strictly diagonally
%      dominant with non-diagonal elements drawn from the uniform distribution 
%      on open interval (a,b)=(0,1).
%
% -- randsdd(...,key,value)
%      Optional key/value pairs pairs arguments are available with keys:
%        - 'complex', if value is true the amat object is complex 
%                     (default false i.e real amat object)
%        - 'class', value can be 'single' or 'double' (default).
%        - 'a', to set a (lower bound of the interval) value (0 by default).
%        - 'b', to set b (upper bound of the interval) value (1 by default).
%
%      See also: fc_amat.random.randn,
%                class amat
%
  p = inputParser; 
  p.addParamValue('complex',false,@islogical); 
  p.addParamValue('class','double',@(x) ismember(lower(x),{'single','double'})); 
  p.addParamValue('a',0,@isscalar); 
  p.addParamValue('b',1,@isscalar); 
  p.parse(varargin{:});
  R=p.Results;
  assert( R.a < R.b , 'a must be less than b!')
  h=R.b-R.a;
  if R.complex
    A=complex(R.a+h*fc_amat.random.rand(N,d,d,R.class),R.a+h*fc_amat.random.rand(N,d,d,R.class));
    s=exp(2*pi*complex(0,1)*rand(N,d,R.class));
  else
    A=R.a+h*fc_amat.random.rand(N,d,d,R.class);
    s=-3+2*randi(2,N,d,R.class); % sign
  end
  tmp=(1+1e-6)*s.*squeeze(sum(abs(A),2)); % N-by-d
  for i=1:d
    A(i,i)=tmp(:,i);
  end
end
